summaryrefslogtreecommitdiffstats
path: root/chrome/common/render_messages.h
diff options
context:
space:
mode:
authorjam@chromium.org <jam@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-05-04 01:47:49 +0000
committerjam@chromium.org <jam@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2011-05-04 01:47:49 +0000
commitbac33eb460f7c94be8d30613ea8ed8804d63d23d (patch)
tree4f78120f455c86ff734f018a67b542668a17e302 /chrome/common/render_messages.h
parentec0800709c0aec729385fe4dce1f9ee578b061c8 (diff)
downloadchromium_src-bac33eb460f7c94be8d30613ea8ed8804d63d23d.zip
chromium_src-bac33eb460f7c94be8d30613ea8ed8804d63d23d.tar.gz
chromium_src-bac33eb460f7c94be8d30613ea8ed8804d63d23d.tar.bz2
Chrome side to allow WebKit layer to use WebPermissionClient to check if access to local storage is allowed.
Review URL: http://codereview.chromium.org/6915017 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@84023 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/common/render_messages.h')
-rw-r--r--chrome/common/render_messages.h28
1 files changed, 18 insertions, 10 deletions
diff --git a/chrome/common/render_messages.h b/chrome/common/render_messages.h
index d7bcc3c..d20b3c6 100644
--- a/chrome/common/render_messages.h
+++ b/chrome/common/render_messages.h
@@ -297,13 +297,21 @@ IPC_MESSAGE_ROUTED2(ViewHostMsg_ContentBlocked,
std::string /* resource identifier */)
// Sent by the renderer process to check whether access to web databases is
-// granted by content settings. This may block and trigger a cookie prompt.
-IPC_SYNC_MESSAGE_ROUTED4_1(ViewHostMsg_AllowDatabase,
- std::string /* origin_url */,
- string16 /* database name */,
- string16 /* database display name */,
- unsigned long /* estimated size */,
- bool /* result */)
+// granted by content settings.
+IPC_SYNC_MESSAGE_CONTROL4_1(ViewHostMsg_AllowDatabase,
+ std::string /* origin_url */,
+ string16 /* database name */,
+ string16 /* database display name */,
+ unsigned long /* estimated size */,
+ bool /* result */)
+
+// Sent by the renderer process to check whether access to DOM Storage is
+// granted by content settings.
+IPC_SYNC_MESSAGE_CONTROL3_1(ViewHostMsg_AllowDOMStorage,
+ int /* render_view_id */,
+ GURL /* origin_url */,
+ DOMStorageType /* type */,
+ bool /* result */)
// Tells the browser that a specific Web database in the current page was
// accessed.
@@ -399,9 +407,9 @@ IPC_MESSAGE_CONTROL1(ViewHostMsg_DnsPrefetch,
// BLOCK means that the plugin should not run nor be allowed to run at all.
// ASK means that the plugin should be initially blocked and the user should
// be asked whether he wants to run the plugin.
-IPC_SYNC_MESSAGE_ROUTED0_2(ViewHostMsg_GetPluginPolicies,
- ContentSetting /* outdated_policy */,
- ContentSetting /* authorize_policy */)
+IPC_SYNC_MESSAGE_CONTROL0_2(ViewHostMsg_GetPluginPolicies,
+ ContentSetting /* outdated_policy */,
+ ContentSetting /* authorize_policy */)
// Notifies when a plugin couldn't be loaded because it's outdated.
IPC_MESSAGE_ROUTED2(ViewHostMsg_BlockedOutdatedPlugin,